@@ -690,14 +690,20 @@ setMethodS3("writeMat", "default", function(con, ..., matVersion="5", onWrite=NU
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     # Argument 'verbose':
     if (inherits(verbose, "Verbose")) {
+      # Use cat() of R.utils here (and not the one in 'base')
+      cat <- R.utils::cat;
     } else if (is.numeric(verbose)) {
       require("R.utils") || throw("Package not available: R.utils");
       verbose <<- Verbose(threshold=verbose);
+      # Use cat() of R.utils here (and not the one in 'base')
+      cat <- R.utils::cat;
     } else {
       verbose <- as.logical(verbose);
       if (verbose) {
         require("R.utils") || throw("Package not available: R.utils");
         verbose <<- Verbose(threshold=-1);
+        # Use cat() of R.utils here (and not the one in 'base')
+        cat <- R.utils::cat;
       }
     }
 
@@ -853,6 +859,9 @@ setMethodS3("writeMat", "default", function(con, ..., matVersion="5", onWrite=NU
 
 ######################################################################
 # HISTORY:
+# 2011-07-24
+# o Now readMat() and writeMat() locally defines cat() (by copying the
+#   one in R.utils), iff R.utils is loaded.
 # 2010-10-29
 # o Now writeMat() gives an error, if non-unique object names
 #   are detected.
